# Ledger Nano S and Nano X Library

This is a stripped down and modified version of the official [btchip-python](https://github.com/LedgerHQ/btchip-python) library.

This stripped down version was made at commit [fe82d7f5638169f583a445b8e200fd1c9f3ea218](https://github.com/LedgerHQ/btchip-python/tree/fe82d7f5638169f583a445b8e200fd1c9f3ea218).

## Changes

- Removed support for Ledger HW.1 and other unused things
